@@ -77,10 +77,12 @@ function( resp , Y=NULL , group = NULL ,  irtmodel ="2PL" ,
   nullY <- is.null(Y)
   
   # define design matrix in case of PCM2
-  if (( irtmodel=="PCM2" ) & (is.null(Q)) & ( is.null(A)) ){ 
-			A <- .A.PCM2( resp ) 
-					}  
-  
+#  if (( irtmodel=="PCM2" ) & (is.null(Q)) & ( is.null(A)) ){ 
+#			A <- .A.PCM2( resp ) 
+#					}  
+    if (( irtmodel=="PCM2" ) & ( is.null(A)) ){ 
+      A <- .A.PCM2( resp ) 
+    }    
   
   
   nitems <- ncol(resp)       # number of items
@@ -726,7 +728,7 @@ function( resp , Y=NULL , group = NULL ,  irtmodel ="2PL" ,
 	ic <- .TAM.ic( nstud , deviance , xsi , xsi.fixed ,
 		beta , beta.fixed , ndim , variance.fixed , G ,
 		irtmodel ,B_orig=B_orig ,  B.fixed , E , est.variance , resp ,
-		est.slopegroups , variance.Npars=variance.Npars )
+		est.slopegroups , variance.Npars=variance.Npars , group )
 
 	#***
 	# calculate counts
@@ -833,6 +835,12 @@ function( resp , Y=NULL , group = NULL ,  irtmodel ="2PL" ,
 	rownames(obji) <- dimnames(A)[[3]]	
 	xsi <- obji
 	
+	 res.hwt <- calc_posterior.v2(rprobs=rprobs , gwt=1+0*gwt , resp=resp , nitems=nitems , 
+                                   resp.ind.list=resp.ind.list , normalization=FALSE , 
+                                   thetasamp.density=thetasamp.density , snodes=snodes ,
+                                   resp.ind=resp.ind	)	
+      res.like <- res.hwt[["hwt"]] 	
+	
   # Output list
   deviance.history <- deviance.history[ 1:iter , ]
   res <- list( "xsi" = xsi ,
@@ -854,7 +862,8 @@ function( resp , Y=NULL , group = NULL ,  irtmodel ="2PL" ,
 			   "AXsi_" = - AXsi ,			   
 			   "se.AXsi" = se.AXsi , 
                "nstud" = nstud , "resp.ind.list" = resp.ind.list ,
-               "hwt" = hwt , "ndim" = ndim ,
+               "hwt" = hwt , "like" = res.like , 
+			   "ndim" = ndim ,
                "xsi.fixed" = xsi.fixed , "beta.fixed" = beta.fixed, "Q" = Q, 
 			   "B.fixed" = B.fixed , "est.slopegroups" = est.slopegroups , "E" = E , "basispar" = basispar,
                "variance.fixed" = variance.fixed ,
